# EasyMQL
An easy-to-use query language for MongoDB.

## Documentation
[EasyMQL](https://vivek-shrikhande.github.io/easy-mql)

## License
[MIT](https://github.com/vivek-shrikhande/easy-mql/blob/main/LICENSE)
